componenttools.iterate_thread_backward_from_component
=====================================================

.. autofunction:: abjad.tools.componenttools.iterate_thread_backward_from_component.iterate_thread_backward_from_component
